SystemOrganization addCategory: #'Tweak-ExtraTests-Tiles'!
SystemOrganization addCategory: #'Tweak-ExtraTests-Books'!
SystemOrganization addCategory: #'Tweak-ExtraTests-Tools'!

CWidgetTest subclass: #CBookTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Tweak-ExtraTests-Books'!

!CBookTest commentStamp: 'tak 5/15/2005 16:33' prior: 0!
CBookTest buildSuite run!

!CBookTest methodsFor: 'testing' stamp: 'tak 5/16/2005 11:41'!
testAdd
	"self debug: #testAdd"
	| window |
	window := CBookWindow new.
	window open.
	window add.
	self waitTick.
	self assert: window player items cursor = 1.
	self assert: window player items size = 1.
	self assert: window book elements size = 1.
	self assert: window book elements first class = CPlayer.
	window close.
! !

!CBookTest methodsFor: 'testing' stamp: 'tak 5/19/2005 16:53'!
testAddRemove
	"self debug: #testAddRemove"
	| book |
	book := CBook new.
	book add.
	book add.
	book add.
	self assert: book cursor = 3.

	"Remove on the cursor"
	book cursor: 2.
	book remove.
	self assert: book selection name = 'page3'.

	"Add after the cursor"
	book cursor: 1.
	book add.
	self assert: book cursor = 2.
! !

!CBookTest methodsFor: 'testing' stamp: 'tak 5/15/2005 22:56'!
testBuildPanel
	"self debug: #testBuildPanel"
	| panel |
	panel := CBookWindow new.
	panel open.
	self assert: panel player = panel book player.
	self assert: panel player items = panel list items.
	panel close! !

!CBookTest methodsFor: 'testing' stamp: 'tak 5/16/2005 17:37'!
testCleanupWhenCostumeChange
	"self debug: #testCleanupWhenCostumeChange"
	| book bookCostume |
	book := CBook open.
	book open.
	CViewerFlap openForTarget: book inWorld: book.
	book view: #small.
	bookCostume := book costume.
	book view: #window.
	self assert: bookCostume container isNil.
	book close.! !

!CBookTest methodsFor: 'testing' stamp: 'tak 5/15/2005 09:06'!
testCostume
	"self debug: #testCostume"
	| book |
	book := CBook new.
	self assert: book costume class = CBookCostume
! !

!CBookTest methodsFor: 'testing' stamp: 'tak 5/19/2005 16:25'!
testDrop
	"self debug: #testDrop"
	| book bookPane rect |
	book := CBook newWindow.
	book costume setupCostume.
	bookPane := book costume book.
	book add.
	bookPane onDrop: (rect := CRectanglePlayer new).
	self waitTick.
	self assert: rect container name = 'page1'.

	"Reject myself"
	bookPane onDrop: book.
	self waitTick.
	self assert: (book container name = 'page') not.! !

!CBookTest methodsFor: 'testing' stamp: 'tak 5/15/2005 17:01'!
testFirstPage
	"self debug: #testFirstPage"
	| book element1 element2 |
	book := CBook new.
	element1 := CRectanglePlayer new.
	element1 name: 'first'.
	element2 := CEllipsePlayer new.
	element2 name: 'second'.
	book add: element1.
	book add: element2.
	self waitTick.
	book cursor: 2.
	self waitTick.
	self assert: book items size = 2.
	self assert: book elements size = 1.
	self assert: book elements first = element2.
! !

!CBookTest methodsFor: 'testing' stamp: 'tak 5/16/2005 17:23'!
testFollowPlayerAfterCostumeChanged
	"self debug: #testFollowPlayerAfterCostumeChanged"
	| book oldCostume |
	book := CBook newWindow.
	book add: CEllipsePlayer new.
	book add: CRectanglePlayer new.
	book open.
	book view: #small.
	oldCostume := book costume.
	book view: #window.
	self assert: oldCostume player = nil.	! !

!CBookTest methodsFor: 'testing' stamp: 'tak 5/22/2005 22:03'!
testView
	"self debug: #testView"
	| book |
	book := CBook new.
	self assert: book view = #animation.
	book view: #window.
	self assert: book view = #window.
	self assert: book costume class = CBookWindow.

	book view: #animation.
	self assert: book view = #animation.
	book costume class = CBookCostume.
! !

CWidgetTest subclass: #CTilesTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Tweak-ExtraTests-Tiles'!

!CTilesTest methodsFor: 'helpers' stamp: 'bf 2/16/2005 16:15'!
makeObject

	^ CTilesTestSubject new! !

!CTilesTest methodsFor: 'helpers' stamp: 'bf 2/16/2005 16:14'!
makeProperty: propertyName for: object

	^ CPropertyTile new
		receiver: object;
		property: propertyName;
		yourself! !

!CTilesTest methodsFor: 'tests' stamp: 'ar 4/15/2007 22:43'!
testAssignment
	| object assignment property expression |
	object := self makeObject.
	object a: 42.

	property := self makeProperty: #a for: object.
	expression := self makeProperty: #b for: object.

	assignment := CAssignmentTile new.
	assignment property: property.
	assignment expression: expression.

	self waitTick.

	self assert: assignment property parent == assignment.
	self assert: assignment expression == expression.! !

CTestCase subclass: #CDebuggerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Tweak-ExtraTests-Tools'!

!CDebuggerTest methodsFor: 'tests-script list' stamp: 'ar 5/13/2005 10:52'!
testScriptListWorksAfterEventBreakPoint
	"Ensure that the script list updates properly after using an event breakpoint."
	| target tracer debugger |
	target := CPlayer new.
	target startScript: #yourself when: {target. #testYourself}.
	target startScript:[target signal: #testYourself] when:{target. #testSignal}.
	target openIn: world.

	tracer := CDebugEventTracer new.
	tracer signaler: target.
	tracer eventName: #testSignal.
	tracer register.

	"this is just so we don't deadlock"
	target startScript:[target signal: #testSignal].
	self waitTick.
	debugger := world elements detect:[:any| any asPlayer isKindOf: CPreDebugger].
	self assert: debugger notNil.
	debugger debugButton fire.
	self waitTick.
	debugger := world elements detect:[:any| any asPlayer isKindOf: CDebugger].

	self assert: debugger notNil.
	self assert: debugger scriptList size = 1.

	debugger complete.
	self waitTick.

	self assert: debugger scriptList size = 2.
! !

CTestCase subclass: #CTextToolTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Tweak-ExtraTests-Tools'!

!CTextToolTest commentStamp: 'tak 5/7/2005 07:24' prior: 0!
CTextToolTest buildSuite run!

!CTextToolTest methodsFor: 'testing' stamp: 'tak 2/19/2006 02:30'!
removeTestFont
	| style fontArray |
	style := TextStyle named: 'BitstreamVeraSans'.
	fontArray := style fontArray
				reject: [:font | font pointSize = 99].
	style newFontArray: fontArray! !

!CTextToolTest methodsFor: 'testing' stamp: 'tak 5/6/2005 19:06'!
testBold
	"self debug: #testBold"
	| tool textEditor |
	tool := CTextTool new.
	textEditor := CTextEditor new.
	textEditor contents: 'Hello'.
	textEditor editor selectAll.

	tool boldButton fire.
	self waitTick.
	self assert: tool boldButton selected.

	tool editor: textEditor editor.
	self waitTick.
	self assert: tool boldButton selected not.

	tool boldButton fire.
	self waitTick.
	self assert: tool boldButton selected.
	self assert: textEditor emphasis = 1.

! !

!CTextToolTest methodsFor: 'testing' stamp: 'tak 5/6/2005 19:14'!
testBoldItalic
	"self debug: #testBoldItalic"
	| tool textEditor |
	tool := CTextTool new.
	textEditor := CTextEditor new.
	textEditor contents: 'Hello'.
	textEditor editor selectAll.

	tool editor: textEditor editor.

	tool boldButton fire.
	tool italicButton fire.
	self waitTick.
	self assert: tool boldButton selected.
	self assert: textEditor emphasis = 3.

! !

!CTextToolTest methodsFor: 'testing' stamp: 'tak 5/6/2005 19:28'!
testFontName
	"self debug: #testFontName"
	| tool textEditor |
	tool := CTextTool new.
	textEditor := CTextEditor new.
	textEditor contents: 'Hello'.
	textEditor editor selectAll.

	tool editor: textEditor editor.
	tool fontNames value: #Accushi.
	self waitTick.
	textEditor contents font name = 'Accushi'.

	tool fontNames value: #Atlanta.
	self waitTick.
	textEditor contents font name = 'Atlanta'.
! !

!CTextToolTest methodsFor: 'testing' stamp: 'tak 2/19/2006 02:35'!
testFontSize
	"self debug: #testFontSize"
	| tool textEditor |
	self removeTestFont.
	tool := CTextTool new.
	tool costume.
	textEditor := CTextEditor new.
	textEditor contents: 'Hello'.
	textEditor editor selectAll.
	tool editor: textEditor editor.
	self waitTick.
	tool fontNames selection: #BitstreamVeraSans.
	self waitTick.
	tool fontSizes selection: 36.
	self waitTick.
	self assert: textEditor contents font name = 'BitstreamVeraSans'.
	self assert: textEditor contents font pointSize = 36.
"	tool fontSize: 99.
	self waitTick.
	self assert: textEditor contents font pointSize = 99."
	self removeTestFont.
! !

!CTextToolTest methodsFor: 'testing' stamp: 'tak 2/19/2006 00:37'!
testNewSize
	"self debug: #testNewSize"
	| tool textEditor |
	tool := CTextTool new.
	tool costume.
	textEditor := CTextEditor new.
	textEditor contents: 'Hello'.
	textEditor editor selectAll.
	tool editor: textEditor editor.
	self waitTick.
	tool fontNames selection: #BitstreamVeraSans.
	self waitTick.
	tool fontSizes selection: 36.
	self waitTick.
	self assert: textEditor contents font name = 'BitstreamVeraSans'.
	self assert: textEditor contents font pointSize = 36! !

!CTextToolTest methodsFor: 'testing' stamp: 'tak 5/10/2005 11:46'!
testOpen
	"self debug: #testOpen"
	| tool |
	self waitTick.
	self assert: (world hand handlesEvent: #keyboardFocusChanged) not.

	tool := CTextTool new.
	tool open.
	self waitTick.
	self assert: (world hand handlesEvent: #keyboardFocusChanged).
	tool close.
	self waitTick.
	self assert: (world hand handlesEvent: #keyboardFocusChanged) not.

	
	

! !

!CTextToolTest methodsFor: 'testing' stamp: 'tak 5/7/2005 19:38'!
testSelectAfterSetFont
	"self debug: #testSelectAfterSetFont"
	| tool textEditor |
	tool := CTextTool new.
	textEditor := CTextEditor new.
	textEditor contents: 'Hello'.
	tool editor: textEditor editor.
	textEditor selectFrom: 1 to: 2.
	self waitTick.
	self assert: textEditor selection font isNil.

	tool fontSizes selection: 24.
	self waitTick.
	self assert: textEditor selection font pointSize = 24.

	textEditor selectFrom: 2 to: 3.
	self waitTick.
	self assert: textEditor selection font isNil.
! !

!CTextToolTest methodsFor: 'testing' stamp: 'tak 5/6/2005 19:17'!
testSelectedBold
	"self debug: #testSelectedBold"
	| tool textEditor textEditor2 |
	tool := CTextTool new.
	textEditor := CTextEditor new.
	textEditor contents: 'Hello'.
	textEditor editor selectAll.

	textEditor2 := CTextEditor new.
	textEditor2 contents: 'Hello' asText allBold.
	textEditor2 editor selectAll.

	tool editor: textEditor editor.
	self waitTick.
	self assert: tool boldButton selected not.

	tool editor: textEditor2.
	self waitTick.
	self assert: tool boldButton selected.
! !

!CTextToolTest methodsFor: 'testing' stamp: 'tak 2/18/2006 23:21'!
testSelectedFontName
	"self debug: #testSelectedFontName"
	| tool textEditor text |
	text := 'Hello' asText.
	text
		addAttribute: (TextFontReference
				toFont: (StrikeFont familyName: 'Accusf' size: 18)).
	tool := CTextTool new.
	tool costume.
	textEditor := CTextEditor new.
	self waitTick.
	textEditor contents: text.
	textEditor editor selectAll.
	tool editor: textEditor editor.
	self waitTick.
	self assert: tool fontNames value = 'Accusf'.
	self assert: tool fontSizes value = 18! !

!CTextToolTest methodsFor: 'testing' stamp: 'tak 5/7/2005 22:25'!
testText
	"This test case is not finished..."
	"self debug: #testText"
	| tool textEditor text |
	tool := CTextTool new.
	textEditor := CTextEditor new.
	text := 'Hello' asText.
	text makeBoldFrom: 1 to: 1.
	text makeItalicFrom: 3 to: 3.
	textEditor contents: text.
	textEditor selectFrom: 1 to: 2.

	tool editor: textEditor editor.
	self waitTick.
	self assert: (textEditor emphasis anyMask: 1).
	self assert: tool boldButton selected.
! !

CObject subclass: #CTilesTestSubject
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Tweak-ExtraTests-Tiles'!

CTilesTestSubject defineFields: '<?xml  version="1.0" ?>
<fields>
	<field toGet="a" toSet="a:" changeEvent="aChanged">a</field>
	<field toGet="b" toSet="b:" changeEvent="bChanged">b</field>
</fields>'!

!CTilesTestSubject methodsFor: 'accessing' stamp: 'bf 2/16/2005 16:16'!
a
	"Answer the a of the receiver"
	<bewareOf: #aChanged>
	^self propertyValueAt: #a! !

!CTilesTestSubject methodsFor: 'accessing' stamp: 'bf 2/16/2005 16:16'!
a: aValue
	"Modify the receiver's a"
	^self propertyValueAt: #a put: aValue with: #aChanged! !

!CTilesTestSubject methodsFor: 'accessing' stamp: 'bf 2/16/2005 16:16'!
b
	"Answer the b of the receiver"
	<bewareOf: #bChanged>
	^self propertyValueAt: #b! !

!CTilesTestSubject methodsFor: 'accessing' stamp: 'bf 2/16/2005 16:16'!
b: aValue
	"Modify the receiver's b"
	^self propertyValueAt: #b put: aValue with: #bChanged! !
